@@ -16,8 +16,6 @@
 Installs and configures Keystone
 """
 
-import uuid
-
 from packstack.installer import basedefs
 from packstack.installer import validators
 from packstack.installer import processors
@@ -75,18 +73,6 @@ def initConfig(controller):
              "NEED_CONFIRM": False,
              "CONDITION": False},
 
-            {"CMD_OPTION": "keystone-admin-token",
-             "PROMPT": "The token to use for the Keystone service api",
-             "OPTION_LIST": [],
-             "VALIDATORS": [validators.validate_not_empty],
-             "DEFAULT_VALUE": uuid.uuid4().hex,
-             "MASK_INPUT": True,
-             "LOOSE_VALIDATION": False,
-             "CONF_NAME": "CONFIG_KEYSTONE_ADMIN_TOKEN",
-             "USE_DEFAULT": True,
-             "NEED_CONFIRM": False,
-             "CONDITION": False},
-
             {"CMD_OPTION": "keystone-admin-email",
              "PROMPT": "Enter the email address for the Keystone admin user",
              "OPTION_LIST": [],
